summaryrefslogtreecommitdiff
path: root/src/scanners.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/scanners.c')
-rw-r--r--src/scanners.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/scanners.c b/src/scanners.c
index 2d5796f..91a7796 100644
--- a/src/scanners.c
+++ b/src/scanners.c
@@ -25495,10 +25495,10 @@ bufsize_t _scan_setext_heading_line(const unsigned char *p) {
}
}
// Scan a horizontal rule line: "...three or more hyphens, asterisks,
// or underscores on a line by themselves. If you wish, you may use
// spaces between the hyphens or asterisks."
-bufsize_t _scan_hrule(const unsigned char *p) {
+bufsize_t _scan_thematic_break(const unsigned char *p) {
const unsigned char *marker = NULL;
const unsigned char *start = p;
@@ -25495,10 +25495,10 @@ bufsize_t _scan_setext_heading_line(const unsigned char *p) {
}
}
-// Scan a horizontal rule line: "...three or more hyphens, asterisks,
+// Scan a thematic break line: "...three or more hyphens, asterisks,
// or underscores on a line by themselves. If you wish, you may use
// spaces between the hyphens or asterisks."